==> haskell-email-validate-2.3.2.21-101.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 email-validate
version:              2.3.2.21
visibility:           public
id:                   email-validate-2.3.2.21-7k0Inpx6EuzEKmxIRZFsX3
key:                  email-validate-2.3.2.21-7k0Inpx6EuzEKmxIRZFsX3
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  9337996626015b054ce339c77ad845c1
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
library-dirs:         /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/loongarch64-linux-ghc-9.6.6/email-validate-2.3.2.21

hs-libraries:         HSemail-validate-2.3.2.21-7k0Inpx6EuzEKmxIRZFsX3
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-email-validate-2.3.2.21-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-email-validate.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 email-validate
version:              2.3.2.21
visibility:           public
id:                   email-validate-2.3.2.21-6BQ3rNhF1qq9n1JEwG6kxE
key:                  email-validate-2.3.2.21-6BQ3rNhF1qq9n1JEwG6kxE
license:              BSD-3-Clause
maintainer:           George Pollard <porges@porg.es>
author:               George Pollard <porges@porg.es>
stability:            experimental
homepage:             https://github.com/Porges/email-validate-hs
synopsis:             Email address validation
description:          Validating an email address string against RFC 5322
category:             Text
abi:                  6aadb4864b0cc99b7bc677568aae9b4f
exposed:              True
exposed-modules:
    Text.Email.Parser Text.Email.QuasiQuotation Text.Email.Validate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
library-dirs:         /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/email-validate-2.3.2.21
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/loongarch64-linux-ghc-9.6.6/email-validate-2.3.2.21

hs-libraries:         HSemail-validate-2.3.2.21-6BQ3rNhF1qq9n1JEwG6kxE
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 template-haskell-2.20.0.0

haddock-interfaces:
    /usr/share/doc/haskell-email-validate/html/email-validate.haddock

haddock-html:         /usr/share/doc/haskell-email-validate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
